import type { App } from 'vue'
import dayjs from 'dayjs'
import relativeTime from 'dayjs/plugin/relativeTime'
import 'dayjs/locale/zh-cn'
import useAppStore from '@/stores/app'

// 加载计算相对时间的插件
dayjs.extend(relativeTime)

/**
 * 对时间进行格式化
 * @param val 时间戳或者时间字符串
 * @param format 时间格式化的格式
 * @returns 格式化后的时间
 */
export const dateFilter = (val: any, format: string = 'YYYY-MM-DD') => {
  if (!isNaN(val)) {
    val = parseInt(val)
  }
  return dayjs(val).format(format)
}

/**
 * 对时间进行格式化
 * @param val 时间戳或者时间字符串
 * @param format 时间格式化的格式
 * @returns 格式化后的时间
 */
const relativeTimeFilter = (val: any) => {
  const appStore = useAppStore()

  if (!isNaN(val)) {
    val = parseInt(val)
  }

  return (
    dayjs()
      // 国际化
      .locale(appStore.language === 'zh' ? 'zh-cn' : 'en')
      // 相对时间
      .to(val)
  )
}

export default (app: App) => {
  app.config.globalProperties.$filters = {
    dateFilter,
    relativeTimeFilter
  }
}
