import useAppStore from '@/stores/app'
import { createI18n } from 'vue-i18n'
import zhLocale from './lang/zh'
import enLocale from './lang/en'

// i18n: 表示 internationalization, 18 表示中间省略 18 个字母

// t 函数的三种使用场景:
// 1. 在 template 中, 通过 $t('msg')
// 2. 在 setup 中, 通过 useI18n() 获取实例, 然后通过实例使用 t 函数: i18n.t('msg')
// 3. 在 js/ts 中, 通过 i18n.global.t('msg')

let i18n: any
const useI18n = () => {
  if (i18n) return i18n

  const messages = {
    zh: zhLocale,
    en: enLocale
  }

  const appStore = useAppStore()

  // https://vue-i18n.intlify.dev/guide/
  i18n = createI18n({
    legacy: false, // 使用 composition api
    globalInjection: true, // 全局注册 t 函数
    locale: appStore.language, // 当前使用语言
    messages, // 语言包数据源对象
    warnHtmlMessage: false // 是否允许并使用 messages 配置项数据中存在 html 格式数据
  })

  // 返回 i18n 实例
  return i18n
}

export default useI18n
