import { createApp } from 'vue'
import App from './App.vue'

import pinia from './stores'
import router from './router'
import { useRouterGuards } from './router/permission'

import registerIcons from './global/register-icons'
// import registerSvgIcons from './assets/icons'

import useI18n from './i18n'

// 初始化样式表
import 'normalize.css'
import './assets/styles/index.scss'

// 引入 svg 注册脚本
import 'virtual:svg-icons-register'
// 获取所有 SymbolId
// import ids from 'virtual:svg-icons-names'
// => ['icon-icon1','icon-icon2','icon-icon3']

// 添加全局属性: 时间格式化过滤器
import registerFilters from '@/global/filters'

// 添加全局指令
import registerDirectives from '@/global/directives'

// 自定义组件
import registerAllComponents from './components'

const app = createApp(App)

app
  .use(pinia)
  .use(router)
  .use(registerIcons)
  .use(useI18n())
  .use(registerFilters)
  .use(registerDirectives)
  .use(registerAllComponents)

// 启用路由守卫
useRouterGuards(router)

app.mount('#app')
